@@ -57,7 +57,7 @@
  *
  * serverobject.c 
  *
- * $Id: serverobject.c,v 1.13 2002/11/08 00:15:11 gstein Exp $
+ * $Id: serverobject.c,v 1.16 2003/02/28 04:38:16 grisha Exp $
  *
  */
 
@@ -117,30 +117,20 @@ static PyObject *server_register_cleanup(serverobject *self, PyObject *args)
     cleanup_info *ci;
     PyObject *handler = NULL;
     PyObject *data = NULL;
-    PyObject *Req = NULL;
     requestobject *req = NULL;
 
-    if (! PyArg_ParseTuple(args, "OO|O", &Req, &handler, &data))
+    if (! PyArg_ParseTuple(args, "OO|O", &req, &handler, &data))
 	return NULL; 
 
-    if (! PyObject_HasAttrString(Req, "_req")) {
-	PyErr_SetString(PyExc_ValueError, "first argument must be a Request object");
-	return NULL;
+    if (! MpRequest_Check(req)) {
+        PyErr_SetString(PyExc_ValueError, 
+                        "first argument must be a request object");
+        return NULL;
     }
-    else {
-
-	req = (requestobject *) PyObject_GetAttrString(Req, "_req");
-
-	if (! MpRequest_Check(req)) {
-	    PyErr_SetString(PyExc_ValueError, 
-			    "first argument must be a request object");
-	    return NULL;
-	}
-	else if(!PyCallable_Check(handler)) {
-	    PyErr_SetString(PyExc_ValueError, 
-			    "second argument must be a callable object");
-	    return NULL;
-	}
+    else if(!PyCallable_Check(handler)) {
+        PyErr_SetString(PyExc_ValueError, 
+                        "second argument must be a callable object");
+        return NULL;
     }
     
     ci = (cleanup_info *)malloc(sizeof(cleanup_info));
@@ -187,19 +177,19 @@ static struct memberlist server_memberlist[] = {
     /* XXX implement module_config ? */
     /* XXX implement lookup_defaults ? */
     /* XXX implement server_addr_rec ? */
-    {"timeout",            T_INT,       OFF(timeout),            RO},
-    {"keep_alive_timeout", T_INT,       OFF(keep_alive_timeout), RO},
+    {"timeout",            NULL,        NULL,                    RO},
+    {"keep_alive_timeout", NULL,        NULL,                    RO},
     {"keep_alive_max",     T_INT,       OFF(keep_alive_max),     RO},
     {"keep_alive",         T_INT,       OFF(keep_alive),         RO},
     /* XXX send_buffer_size gone. where? document */
-    //{"send_buffer_size",   T_INT,       OFF(send_buffer_size),   RO},
+    /*{"send_buffer_size",   T_INT,       OFF(send_buffer_size),   RO},*/
     {"path",               T_STRING,    OFF(path),               RO},
     {"pathlen",            T_INT,       OFF(pathlen),            RO},
     /* XXX names */
     /* XXX wild names */
     /* XXX server_uid and server_gid seem gone. Where? Document. */
-    //{"server_uid",         T_INT,       OFF(server_uid),         RO},
-    //{"server_gid",         T_INT,       OFF(server_gid),         RO},
+    /*{"server_uid",         T_INT,       OFF(server_uid),         RO},*/
+    /*{"server_gid",         T_INT,       OFF(server_gid),         RO},*/
     /* XXX Document limit* below. Make RW? */
     {"limit_req_line",       T_INT,       OFF(limit_req_line),     RO},
     {"limit_req_fieldsize",  T_INT,       OFF(limit_req_fieldsize),RO},
@@ -272,6 +262,12 @@ static PyObject * server_getattr(serverobject *self, char *name)
     else if (strcmp(name, "restart_time") == 0) {
       return PyInt_FromLong((long)ap_scoreboard_image->global->restart_time);
     }
+    else if (strcmp(name, "timeout") == 0) {
+      return PyLong_FromLongLong(self->server->timeout);
+    }
+    else if (strcmp(name, "keep_alive_timeout") == 0) {
+	return PyLong_FromLongLong(self->server->keep_alive_timeout);
+    }
     else
 	return PyMember_Get((char *)self->server, server_memberlist, name);
 
